<template>
  <div class="app-container">
    <el-row :gutter="20">
      <el-col :span="4" :xs="24">
        <div class="head-container">
          <el-input v-model="areaName" placeholder="请输入区块名称" clearable size="small" prefix-icon="el-icon-search"
            style="margin-bottom: 20px" />
        </div>
        <div class="head-container">
          <el-tree :data="areaOptions" :props="defaultProps" :expand-on-click-node="false" :filter-node-method="filterNode" ref="tree"
            node-key="id" default-expand-all highlight-current @node-click="handleNodeClick" />
        </div>
      </el-col>
      <el-col :span="20" :xs="24">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
          <el-form-item label="计量类别" prop="meterCls">
            <el-select v-model="queryParams.meterCls">
              <el-option v-for="item in emsClsOptions" :label="item.name" :value="item.code" :key="item.code" />
            </el-select>
          </el-form-item>
          <el-form-item label="设备代码" prop="deviceCode">
            <el-input v-model="queryParams.deviceCode" placeholder="请输入设备代码" clearable @keyup.enter.native="handleQuery" />
          </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd" v-hasPermi="['ems:device:add']">新增
            </el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
              v-hasPermi="['ems:device:edit']">修改</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
              v-hasPermi="['ems:device:remove']">删除</el-button>
          </el-col>
          <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="deviceList" @selection-change="handleSelectionChange">
          <el-table-column type="selection" width="55" align="center" />
          <el-table-column label="计量对象" align="left" prop="objName" width="300px">
            <template slot-scope="scope">
              <span>{{ "（" + getObjTypeName(scope.row.objType) + "）"+ scope.row.objName }}</span>
            </template>
          </el-table-column>
          <el-table-column label="计量标签" align="center" prop="objTag">
            <template slot-scope="scope">
              {{formatDict(scope.row.objTag,'objTagOptions')}}
            </template>
          </el-table-column>

<!--          <el-table-column label="计量标签" align="center" prop="objTag">-->
<!--            <template slot-scope="scope">-->
<!--                  <span-->
<!--                    :style="{-->
<!--                      padding: '6px 12px',-->
<!--                      borderRadius: '4px',-->
<!--                      display: 'inline-block',-->
<!--                      textAlign: 'center',-->
<!--                      cursor: 'pointer',-->
<!--                      color: (scope.row.objTag === 0) ? '#000' : '#000',-->
<!--                      backgroundColor: (scope.row.objTag === 0) ? '#add8e6' : (scope.row.objTag === 1) ? '#ffff99' : '',-->
<!--                      minWidth: '70px',-->
<!--                      height: '35px',-->
<!--                      textAlign: 'center'-->
<!--                    }"-->
<!--                  >-->
<!--             {{ formatDict(scope.row.objTag, 'objTagOptions') }}-->
<!--                   </span>-->
<!--          </template>-->
<!--          </el-table-column>-->
          <el-table-column label="设备代码" align="center" prop="deviceCode" />
          <el-table-column label="计量类别" align="center" prop="meterCls">
            <template slot-scope="scope">
              <span>{{ getMeterClsName(scope.row.meterCls) }}</span>
            </template>
          </el-table-column>
          <el-table-column label="采集方式" align="center" prop="colMode">
            <template slot-scope="scope">
              <span>{{ getColModeName(scope.row.colMode) }}</span>
            </template>
          </el-table-column>
          <el-table-column label="采集周期" align="center" prop="colCycle">
            <template slot-scope="scope">
              <span>{{ getColCycleName(scope.row.colCycle) }}</span>
            </template>
          </el-table-column>
          <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
            <template slot-scope="scope">
              <el-button size="mini" type="text"  icon="el-icon-edit" @click="handleUpdate(scope.row)" v-hasPermi="['basecfg:device:edit']">
                修改</el-button>
              <el-button size="mini" type="text" icon="el-icon-delete" class="deleteBtn" @click="handleDelete(scope.row)" v-hasPermi="['basecfg:device:remove']">
                删除</el-button>

            </template>
          </el-table-column>
        </el-table>

        <pagination v-show="total>0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
          @pagination="getList" />

        <!-- 添加或修改计量设备对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
          <el-form ref="form" :model="form" :rules="rules" label-width="80px">
            <el-form-item label="设备归属" prop="deviceCode">
              <el-select v-model="form.areaCode" @change="handleAreaSelect">
                <el-option v-for="item in areaOptions" :label="item.label" :value="item.id" :key="item.id" />
              </el-select>
            </el-form-item>
            <el-form-item label="计量类别" prop="meterCls">
              <el-select v-model="form.meterCls">
                <el-option v-for="item in emsClsOptions" :label="item.name" :value="item.code" :key="item.code" />
              </el-select>
            </el-form-item>
            <el-form-item label="设备代码" prop="deviceCode">
              <el-input v-model="form.deviceCode" placeholder="请输入设备代码" />
            </el-form-item>
            <el-form-item label="计量分类" prop="objType">
              <el-select v-model="form.objType" @change="changeObjOptions">
                <el-option v-for="item in objTypeOptions" :label="item.name" :value="item.code" :key="item.code" />
              </el-select>
            </el-form-item>
            <el-form-item label="计量对象" prop="objCode">
              <treeselect v-model="objCode" :options="objCodeOptions" :show-count="true" placeholder="请选择计量对象" ref="treeObjCodeOptions" />
            </el-form-item>
            <el-form-item label="计量标签" prop="objTag">
              <el-radio-group v-model="form.objTag" size="medium">
                <el-radio v-for="(item, index) in objTagOptions" :key="index" :label="item.code" :disabled="item.disabled">{{item.name}}
                </el-radio>
              </el-radio-group>
            </el-form-item>
            <el-form-item label="采集方式" prop="colMode">
              <el-select v-model="form.colMode" @change="colModeChange">
                <el-option v-for="item in colModeOptions" :label="item.name" :value="item.code" :key="item.code" />
              </el-select>
            </el-form-item>
            <el-form-item label="采集周期" prop="colCycle">
              <el-select v-model="form.colCycle" :disabled="form.colMode === 1">
                <el-option v-for="item in colCycleOptions" :label="item.name" :value="item.code" :key="item.code" />
              </el-select>
            </el-form-item>
            <el-form-item label="倍率" prop="magnification">
              <el-input v-model="form.magnification" oninput="value=value.replace(/^0(0+|\d+)|[^\d]+/g,'')" placeholder="请输入倍率" />
            </el-form-item>
            <el-form-item label="规格描述" prop="specDesc">
              <el-input v-model="form.specDesc" placeholder="请输入规格描述" />
            </el-form-item>
          </el-form>
          <div slot="footer" class="dialog-footer">
            <el-button type="primary" @click="submitForm">确 定</el-button>
            <el-button @click="cancel">取 消</el-button>
          </div>
        </el-dialog>
      </el-col>
    </el-row>
  </div>
</template>

<script>
import { listDevice, getDevice, delDevice, addDevice, updateDevice } from '@/api/device/meterDevice'
import { devTreeByFacs } from '@/api/device/device'
import { areaTreeSelect, areaTreeSelectByCode } from '@/api/basecfg/area'
import { listBuildingByArea } from '@/api/basecfg/building'
import Treeselect from '@riophae/vue-treeselect'
import '@riophae/vue-treeselect/dist/vue-treeselect.css'

export default {
  name: 'Device',
  components: { Treeselect },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 计量设备表格数据
      deviceList: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      // 区域名称
      areaName: undefined,
      objCodeOptions: [],
      areaOptions: [],
      buildingOptions: [],
      selectObjCode: null,
      objCode: null,
      defaultProps: {
        children: 'children',
        label: 'label'
      },
      // 能源分类树
      emsClsOptions: [
        { code: 45, name: '电表' },
        { code: 70, name: '水表' }
      ],
      objTypeOptions: [
        { code: 1, name: '区块' },
        { code: 2, name: '设备' }
      ],
      objTagOptions: [
        { code: 0, name: '公摊表' },
        { code: 1, name: '个户表' }
      ],
      colCycleOptions: [
        { code: 0, name: '实时' },
        { code: 1, name: '分钟' },
        { code: 2, name: '小时' },
        { code: 3, name: '天' },
        { code: 4, name: '月' }
      ],
      colModeOptions: [
        { code: 0, name: '自动抄表' },
        { code: 1, name: '手动抄表' }
      ],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        areaCode: null,
        bldgCode: null,
        deviceCode: null,
        meterCls: null,
        objType: null,
        objCode: null,
        objName: null,
        objTag: null,
        colCycle: null,
        colMode: null,
        magnification: null,
        specDesc: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        areaCode: [{ required: true, message: '选择服务区', trigger: 'blur' }],
        deviceCode: [{ required: true, message: '设备代码不能为空', trigger: 'blur' }],
        meterCls: [{ required: true, message: '计量类别不能为空', trigger: 'blur' }],
        objType: [{ required: true, message: '计量对象类型 1-区块 2-设备不能为空', trigger: 'change' }],
        objCode: [{ required: true, message: '计量对象编码不能为空', trigger: 'blur' }]
      }
    }
  },
  watch: {
    objCode: {
      handler(id) {
        if (id) {
          const option = this.$refs.treeObjCodeOptions.getNode(id)
          this.objCode = option.id
          this.form.objCode = option.id

          if (this.form.objType === 1) {
            if (option.raw.tier === 'Area') {
              this.form.objSubType = 1
            } else if (option.raw.tier === 'Building') {
              this.form.objSubType = 2
            } else if (option.raw.tier === 'Zoning') {
              this.form.objSubType = 3
            }
          } else if (this.form.objType === 2) {
            if (option.raw.tier === 'Facs') {
              this.form.objSubType = 1
            } else if (option.raw.tier === 'Device') {
              this.form.objSubType = 2
            }
          }
        }
      }
    },
    // 根据名称筛选区域树
    areaName(val) {
      this.$refs.tree.filter(val)
    }
  },
  created() {
    this.getAreaTree('Area')
    this.getList()
  },
  methods: {
    colModeChange(val) {
      if (val === 1) {
        this.form.colCycle = 4
      } else {
        this.form.colCycle = null
      }
    },
    /** 查询计量设备列表 */
    getList() {
      this.loading = true
      listDevice(this.queryParams).then(response => {
        this.deviceList = response.rows
        this.total = response.total
        this.loading = false
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        deviceCode: null,
        meterCls: null,
        meterObjType: null,
        objSubType: null,
        objCode: null,
        colCycle: null,
        colMode: null,
        specDesc: null
      }
      this.objCode = null
      this.resetForm('form')
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加计量设备'
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const id = row.id || this.ids
      getDevice(id).then(response => {
        this.form = response.data
        this.open = true
        this.title = '修改计量设备'
        console.log("更新的数据:", this.form)
      })

      this.objCode = row.objCode
      if (row.objType === 1) {
        areaTreeSelectByCode('Area', row.areaCode).then(response => {
          this.objCodeOptions = response.data
        })
      } else if (row.objType === 2) {
        devTreeByFacs(row.areaCode).then(response => {
          this.objCodeOptions = response.data

        })
      }
    },
    handleAreaSelect(areaCode) {
      listBuildingByArea(areaCode).then(response => {
        this.buildingOptions = response.data
      })
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateDevice(this.form).then(response => {
              this.$modal.msgSuccess('修改成功')
              this.open = false
              this.getList()
            })
          } else {
            addDevice(this.form).then(response => {
              this.$modal.msgSuccess('新增成功')
              this.open = false
              this.getList()
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids
      this.$modal
        .confirm('是否确认删除计量设备编号为"' + ids + '"的数据项？')
        .then(function() {
          return delDevice(ids)
        })
        .then(() => {
          this.getList()
          this.$modal.msgSuccess('删除成功')
        })
        .catch(() => {})
    },
    formatDict(val, options, key = 'code', text = 'name') {
      let name = ''
      this[options].forEach(item => {
        if (val === item[key]) {
          name = item[text]
        }
      })
      return name
    },
    getMeterClsName(meterCls) {
      const clsMap = {
        45: '电表',
        70: '水表'
      }
      return clsMap[meterCls] || '未知'
    },
    getObjTypeName(objType) {
      const typeMap = {
        1: '区块',
        2: '设备'
      }
      return typeMap[objType] || '未知'
    },
    getColCycleName(colCycle) {
      const cycleMap = {
        0: '实时',
        1: '分钟',
        2: '小时',
        3: '天',
        4: '月'
      }
      return cycleMap[colCycle] || ''
    },
    getColModeName(colMode) {
      const modeMap = {
        0: '自动抄表',
        1: '手动抄表'
      }
      return modeMap[colMode] || '未知'
    },
    /** 查询区域树结构 */
    getAreaTree(tier) {
      areaTreeSelect(tier).then(response => {
        this.areaOptions = response.data
      })
    },
    // 筛选节点
    filterNode(value, data) {
      if (!value) return true
      return data.label.indexOf(value) !== -1
    },
    // 节点单击事件
    handleNodeClick(data) {
      this.queryParams.areaCode = data.id
      this.handleQuery()
    },
    changeObjOptions(objType) {
      if (objType === 1) {
        areaTreeSelectByCode('Area', this.form.areaCode).then(response => {
          this.objCodeOptions = response.data
        })
      } else if (objType === 2) {
        const devcCategory = 'E';
        devTreeByFacs(this.form.areaCode, devcCategory).then(response => {
          this.objCodeOptions = response.data
          console.log("计量对象",this.objCodeOptions)
        })
      }
    }
  }
}
</script>
